@@ -21,4 +21,10 @@ def create(arguments: Dict[str, Any]) -> Any:
         creator_func = _PLUGINS[resource_type]
     except KeyError:
         raise ValueError(f"unknown resource type {resource_type!r}") from None
-    return creator_func(args_copy)
+    credentials = None
+    application_id = None
+    if "credentials" in args_copy:
+        credentials = args_copy.pop("credentials")
+    if "application_id" in args_copy:
+        application_id = args_copy.pop("application_id")
+    return creator_func(args_copy, credentials=credentials, application_id=application_id)
