@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
-
-from matos_aws_provider.lib import factory
 from typing import Any, Dict
+from matos_aws_provider.lib import factory
 from matos_aws_provider.lib.base_provider import BaseProvider
 
 
 class AwsCloudFront(BaseProvider):
+    """AWS cloud front plugin"""
+
     def __init__(self, resource: Dict, **kwargs) -> None:
         """
         Construct cloud front service
@@ -35,6 +36,7 @@ class AwsCloudFront(BaseProvider):
         return resource
 
     def get_distribution(self, distribution_id):
+        """Get distribution resource."""
         response = self.conn.get_distribution(Id=distribution_id)
         if "ResponseMetadata" in response:
             del response["ResponseMetadata"]
@@ -42,4 +44,5 @@ class AwsCloudFront(BaseProvider):
 
 
 def register() -> Any:
+    """Register plugin"""
     factory.register("cloudfront", AwsCloudFront)
