@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
-
-from matos_aws_provider.lib import factory
 from typing import Any, Dict
+from matos_aws_provider.lib import factory
 from matos_aws_provider.lib.base_provider import BaseProvider
 
 
 class AwsEip(BaseProvider):
+    "Aws eip plugin class"
+
     def __init__(self, resource: Dict, **kwargs) -> None:
         """
         Construct cluster service
@@ -36,4 +37,5 @@ class AwsEip(BaseProvider):
 
 
 def register() -> Any:
+    """Register plugin"""
     factory.register("eip", AwsEip)
