@@ -52,9 +52,21 @@ class AwsFilesystem(BaseProvider):
         self.filesystem_details = {
             **self.filesystem,
             "BackupPolicy": backup_policy,
+            "AccessPoints":self.get_access_points(self.filesystem["FileSystemId"])
         }
         return self.filesystem_details
 
+    def get_access_points(self,file_system_id):
+        """
+        Get access point corresponding to the file system id.
+        Parameters:
+        -file_system_id: Id of the file system
+        """
+        resp = self.conn.describe_access_points(
+            FileSystemId=file_system_id
+        )
+        return resp.get("AccessPoints",[])
+
 
 def register() -> None:
     "Register plugin"
