@@ -1,22 +1,24 @@
 # -*- coding: utf-8 -*-
-from matos_aws_provider.lib import factory
 from typing import Any
+import logging
+from matos_aws_provider.lib import factory
 from matos_aws_provider.lib.base_provider import BaseProvider
-from matos_aws_provider.lib.log import get_logger
 
-logger = get_logger()
+logger = logging.getLogger(__name__)
 
 
 class AwsIAM(BaseProvider):
+    """AWS iam plugin"""
     def __init__(
         self,
         resource: dict,
         **kwargs,
     ) -> None:
-        """ """
+        """Constructor method"""
         super().__init__(**kwargs, client_type="iam")
 
     def get_inventory(self) -> Any:
+        """Get inventory asset"""
         return None
 
     def get_resources(self) -> Any:
@@ -42,4 +44,5 @@ class AwsIAM(BaseProvider):
 
 
 def register() -> None:
+    """Register plugin"""
     factory.register("iam", AwsIAM)
