@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
-
-from matos_aws_provider.lib import factory
 from typing import Any, Dict
+from matos_aws_provider.lib import factory
 from matos_aws_provider.lib.base_provider import BaseProvider
 
 
 class AwsSSM(BaseProvider):
+    """AWS ssm plugin"""
     def __init__(self, resource: Dict, **kwargs) -> None:
         """
         Construct SSM service
@@ -38,6 +38,7 @@ class AwsSSM(BaseProvider):
         return resource
 
     def describe_document_permission(self, document_name, permission_type="Share"):
+        """Describe document permission"""
         response = self.conn.describe_document_permission(
             Name=document_name,
             PermissionType=permission_type,
@@ -48,4 +49,5 @@ class AwsSSM(BaseProvider):
 
 
 def register() -> Any:
+    """Register plugin"""
     factory.register("ssm", AwsSSM)
