@@ -20,8 +20,11 @@ class Provider(Connection):
         Class constructor method
         """
         super().__init__(**kwargs)
+        self.credentials = kwargs.get("credentials", None)
+        self.application_id = kwargs.get("application_id", None)
         loader.load_plugins(get_package())
         self.service_factory = factory
+        self.resource_type = kwargs.get("resource_type", None)
 
     def get_assets(self, **kwargs):
         """
@@ -32,7 +35,11 @@ class Provider(Connection):
         lock = threading.Lock()
 
         def fetch_discovery_details(rsc_type):
-            service_discovery = self.service_factory.create({"type": rsc_type})
+            service_discovery = self.service_factory.create({
+                "type": rsc_type,
+                "credentials": self.credentials,
+                "application_id": self.application_id
+            })
             result = service_discovery.get_inventory()
 
             if result is None:
@@ -46,6 +53,8 @@ class Provider(Connection):
 
         service_map = self.service_factory.fetch_plugins()
         for rsc_type, _ in service_map.items():
+            if self.resource_type and self.resource_type != rsc_type:
+                continue
             thread = threading.Thread(target=fetch_discovery_details, args=(rsc_type,))
             thread.start()
             threads.append(thread)
@@ -74,6 +83,8 @@ class Provider(Connection):
 
         threads = []
         for resource in resource_list:
+            if self.resource_type and self.resource_type != resource.get("type"):
+                continue
             thread = threading.Thread(target=fetch_resource_details, args=(resource,))
             thread.start()
             threads.append(thread)
@@ -82,8 +93,12 @@ class Provider(Connection):
         return resource_inventories
 
     def _get_assets_inventory(self, resource, **kwargs):
+        resource.update({"credentials": self.credentials})
+        resource.update({"application_id": self.application_id})
         cloud_resource = self.service_factory.create(resource)
         resource_details = cloud_resource.get_resources()
         if resource_details:
             resource.update(details=resource_details)
+        resource.pop("credentials")
+        resource.pop("application_id")
         return resource
